@@ -3,19 +3,20 @@ from hkube_python_wrapper.util.encoding import Encoding
 
 
 class DataRequest:
+    ping_times = []
 
     def __init__(self, reqDetails):
         encoding = reqDetails.get('encoding')
         address = reqDetails.get('address')
         timeout = reqDetails.get('timeout')
         networkTimeout = reqDetails.get('networkTimeout')
+        tasks = reqDetails.get('tasks')
         options = {
-            u'tasks': reqDetails.get('tasks'),
-            u'taskId': reqDetails.get('taskId'),
-            u'dataPath': reqDetails.get('dataPath')
+            u'tasks': tasks
         }
+        self.tasks = tasks
         self.encoding = Encoding(encoding)
-        content = self.encoding.encode(options, plain_encode=True)
+        content = self.encoding.encode(options, plainEncode=True)
         self.request = dict()
         self.request.update(address)
         self.request.update({"content": content, "timeout": timeout, "networkTimeout": networkTimeout})
@@ -24,10 +25,20 @@ class DataRequest:
         try:
             print('tcp://' + self.request['host'] + ':' + str(self.request['port']))
             adapter = ZMQRequest(self.request)
-            response = adapter.invokeAdapter()
-            return (len(response), self.encoding.decode(response))
+            responseFrames = adapter.invokeAdapter()
+            results = []
+            for i in range(0, int(len(responseFrames)/2)):
+                header = responseFrames[i*2]
+                content = responseFrames[i*2+1]
+                decoded = self.encoding.decode_separately(header, content)
+                results.append((len(content), decoded))
+            DataRequest.ping_times.append(adapter.pingTime)
+            return results
         except Exception as e:
-            return 0, self._createError('unknown', str(e))
+            results = []
+            for _ in self.tasks:
+                results.append((0, self._createError('unknown', str(e))))
+            return results
         finally:
             adapter.close()
 
